@@ -91,7 +91,7 @@ if mscolab_settings.__dict__.get('enable_basic_http_authentication', False):
 
 def initialize_managers(app):
     sockio, cm, fm = setup_managers(app)
-    # initiatializing socketio and db
+    # initializing socketio and db
     app.wsgi_app = socketio.Middleware(socketio.server, app.wsgi_app)
     sockio.init_app(app)
     db.init_app(app)
@@ -231,6 +231,9 @@ def message_attachment():
     p_id = request.form.get("p_id", None)
     message_type = MessageType(int(request.form.get("message_type")))
     user = g.user
+    users = fm.fetch_users_without_permission(int(p_id), user.id)
+    if users is False:
+        return jsonify({"success": False, "message": "Could not send message. No file uploaded."})
     if file is not None:
         with fs.open_fs('/') as home_fs:
             file_dir = fs.path.join(APP.config['UPLOAD_FOLDER'], p_id)
@@ -436,7 +439,7 @@ def modify_bulk_permissions():
     success = fm.modify_bulk_permission(p_id, user, u_ids, new_access_level)
     if success:
         for u_id in u_ids:
-            sockio.sm.emit_new_permission(u_id=u_id, p_id=p_id)
+            sockio.sm.emit_update_permission(u_id, p_id, access_level=new_access_level)
         sockio.sm.emit_project_permissions_updated(user.id, p_id)
         return jsonify({"success": True, "message": "User permissions successfully updated!"})
 
